BlockCompletionStatus

Enum BlockCompletionStatus 

pub enum BlockCompletionStatus {
    Complete(HangulBlock),
    Incomplete(Jamo),
    Empty,
}
The status of attempting to complete a Hangul syllable block.

Variants



Complete(HangulBlock)

The block is complete and can be represented as a HangulBlock.



Incomplete(Jamo)

The block is incomplete, but contains at one Jamo character.



Empty

The block is empty and contains no Jamo characters.