pub enum BlockPopStatus {
PoppedAndNonEmpty(Jamo),
PoppedAndEmpty(Jamo),
None,
}Expand description
The status of popping a Jamo letter from a Hangul syllable block composer.
Variants
PoppedAndNonEmpty(Jamo)
A Jamo letter was popped and the block still has letters remaining.
PoppedAndEmpty(Jamo)
A Jamo letter was popped and the block is now empty.
None
The block is already empty; no letters to pop.