HangulBlockDecompositionOptions

Struct HangulBlockDecompositionOptions 

pub struct HangulBlockDecompositionOptions {
    pub decompose_composites: bool,
    pub jamo_era: JamoUnicodeType,
}
Options for decomposing a HangulBlock into its constituent Jamo characters.

Example:

use hangul_cd::block::{HangulBlock, HangulBlockDecompositionOptions};
use hangul_cd::jamo::{Jamo, JamoUnicodeType};

let block = HangulBlock {
   initial: Jamo::from_compatibility_jamo('ㄱ').unwrap(),
  vowel: Jamo::from_compatibility_jamo('ㅘ').unwrap(),
  final_optional: Some(Jamo::from_compatibility_jamo('ㄳ').unwrap()),
};

let options = HangulBlockDecompositionOptions {
    decompose_composites: true,
    jamo_era: JamoUnicodeType::Compatibility,
};

let decomposed = block.decomposed_vec(&options).unwrap();
assert_eq!(decomposed, vec!['ㄱ', 'ㅗ', 'ㅏ', 'ㄱ', 'ㅅ']);

Fields

decompose_composites: bool

Whether to decompose composite Jamo into their singular components.

jamo_era: JamoUnicodeType

The Unicode era of the Jamo characters to use in decomposition.