Character

Enum Character 

pub enum Character {
    NonHangul(char),
    Hangul(Jamo),
}
An enum representing either a Hangul Jamo character or a non-Hangul character. Archaic or non-standard jamo like ᅀ will be classified as NonHangul because they are not used in standard modern Hangul syllable composition.

Variants



NonHangul(char)



Hangul(Jamo)

Implementations

Source

impl Character

pub fn from_char(c: char) -> Result<Self, JamoError>

Determines the type of Hangul letter for a given character. Archaic or non-standard jamo like ᅀ will be classified as NonHangul because they are not used in standard modern Hangul syllable composition. Classifies a character as Hangul jamo or non-Hangul and returns the appropriate Character enum variant.

Example:

use hangul_cd::jamo::{
    Character,
    Jamo,
    JamoConsonantSingular,
    JamoVowelSingular,
    JamoVowelComposite,
    JamoConsonantComposite,
};

// Valid Hangul consonant
assert_eq!(
    Character::from_char('ㄱ').unwrap(),
    Character::Hangul(Jamo::Consonant(JamoConsonantSingular::Giyeok))
);

// Valid Hangul vowel
assert_eq!(
    Character::from_char('ㅏ').unwrap(),
    Character::Hangul(Jamo::Vowel(JamoVowelSingular::A))
);

// Valid composite consonant
assert_eq!(
    Character::from_char('ㄲ').unwrap(),
    Character::Hangul(Jamo::CompositeConsonant(JamoConsonantComposite::SsangGiyeok))
);

// Valid composite vowel
assert_eq!(
    Character::from_char('ㅘ').unwrap(),
    Character::Hangul(Jamo::CompositeVowel(JamoVowelComposite::Wa))
);

// Non-Hangul character
assert_eq!(
    Character::from_char('A').unwrap(),
    Character::NonHangul('A')
);
pub fn jamo(&self) -> Option<&Jamo>

Returns the Jamo if the Character is a Hangul jamo, or None otherwise.