Module string

Module string 

A module for working with strings mixing Hangul and non-Hangul characters.

Structs

StringComposer
A composer struct that manages the composition of strings of text consisting of multiple words, including both Hangul words and non-Hangul text.

Enums

StringError
An error type for StringComposer operations.