pub enum WordError {
BlockError(BlockError),
JamoError(JamoError),
CouldNotStartNewBlock(char, BlockPushResult),
NothingToPop,
CannotCompleteCurrentBlock(Jamo),
}Expand description
A composer for a single Hangul word, made up of multiple syllable blocks.
Variants
BlockError(BlockError)
Occurs when there is an error related to syllable blocks.
JamoError(JamoError)
Occurs when there is an error related to Jamo letters.
CouldNotStartNewBlock(char, BlockPushResult)
Tried to start a new block while pushing Jamo, but it was not possible.
The reason is provided in the BlockPushResult.
NothingToPop
Tried popping from an empty word (no Jamo to pop).
CannotCompleteCurrentBlock(Jamo)
Tried to complete the current block, but it only contains one Jamo.