pub enum WordPushResult {
Continue,
InvalidHangul,
NonHangul,
}Expand description
The result of attempting to push a character into the HangulWordComposer.
Variants
Continue
The character was successfully pushed and composition can continue.
InvalidHangul
The character could not be pushed because it would result in an invalid Hangul syllable.
NonHangul
The character was not pushed because it is not a Hangul character.