pub enum BlockError {
JamoError(JamoError),
InvalidBlockRepresentation(u32),
InvalidJamoContext(Jamo, JamoPosition, JamoUnicodeType),
InvalidComponentRepresentation(u32),
JamoInInvalidPosition(Jamo, JamoPosition),
}Expand description
Errors that can occur when working with Hangul syllable blocks.
Variants
JamoError(JamoError)
An error related to Jamo operations.
InvalidBlockRepresentation(u32)
Occurs when a codepoint to represent a Hangul syllable block is invalid. This happens when converting a block to a codepoint, or when trying to create a block from a codepoint that does not correspond to a valid Hangul syllable.
InvalidJamoContext(Jamo, JamoPosition, JamoUnicodeType)
Occurs when a Jamo letter is not valid in the context of Hangul syllable composition, given its position and the Unicode era (modern or compatibility) being used.
InvalidComponentRepresentation(u32)
Occurs when a codepoint meant to represent a Jamo letter is invalid and cannot be used in Hangul syllable composition or decomposition.
JamoInInvalidPosition(Jamo, JamoPosition)
Occurs when a Jamo letter is in an invalid position for Hangul; for example, a vowel in the initial position.