BlockPushResult

Enum BlockPushResult 

pub enum BlockPushResult {
    Success,
    StartNewBlockNoPop,
    PopAndStartNewBlock,
    InvalidHangul,
    NonHangul,
}
Result of pushing a Jamo letter into a Hangul syllable block composer.

Variants



Success

The Jamo letter was successfully pushed into the block composer.



StartNewBlockNoPop

The Jamo letter could not be pushed because it would create an invalid Hangul syllable. However, the letter is a valid initial consonant to begin a new syllable block, so the caller should start a new block without popping any Jamo from this one.



PopAndStartNewBlock

The Jamo letter could not be pushed because it would create an invalid Hangul syllable. The letter is not a valid initial consonant, so the caller should pop the last Jamo from this block and use it to start a new block.



InvalidHangul

The Jamo letter is not valid in the context of Hangul syllable composition. For example, pushing a vowel when an initial consonant is expected.



NonHangul

The Jamo letter is not valid Hangul.